package MojoCoreMantainer;
use Mojo::Role;

sub mantaining_mojo {
  say "I'm making improvements for Mojolicious..."
}

1;
